<?php
/*
Copyright 2011  Mobile Sentience LLC  (email : oss@mobilesentience.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
                                                                 
*/

if(!function_exists('CompareByOperator')){
	function CompareByOperator($lhs, $op, $rhs){
		if(!isset($lhs) || !isset($op) || !isset($rhs) || strlen($op) == 0)
			return false;

		switch($op){
			case '==': // is equal to
				if(is_numeric($rhs)){
					return $lhs == $rhs;
				}else{
					return strcmp($lhs, $rhs) === 0;
				}
				break;
			case '==i': // case insensitive string compare
				return strcasecmp($lhs, $rhs) === 0;
				break;
			case '!=': // is equal to
				if(is_numeric($rhs)){
					return $lhs != $rhs;
				}else{
					return strcmp($lhs, $rhs) !== 0;
				}
				break;
			case '!=i': // is not equal to
				return strcasecmp($lhs, $rhs) === 0;
				break;
			case '>': // is greater than
				if(is_numeric($rhs)){
					return $lhs > $rhs;
				}else{
					return strcmp($lhs, $rhs) > 0;
				}
				break;
			case '<': // is less than
				if(is_numeric($rhs)){
					return $lhs < $rhs;
				}else{
					return strcmp($lhs, $rhs) < 0;
				}
				break;
			case '>=': // is greater than or equal to
				if(is_numeric($rhs)){
					return $lhs >= $rhs;
				}else{
					return strcmp($lhs, $rhs) >= 0;
				}
				break;
			case '<=': // is less than or equal to
				if(is_numeric($rhs)){
					return $lhs <= $rhs;
				}else{
					return strcmp($lhs, $rhs) <= 0;
				}
				break;
			case '~=': // matches regular expression
				return preg_match('/' . $rhs . '/', $lhs, $matches);
				break;
			case '!~': // does not match regular expression
				return !preg_match('/' . $rhs . '/', $lhs, $matches);
				break;
		}

	 	return false;

	}
}

if(!function_exists('VerifyRule_author')){
	function VerifyRule_author($rule){
		if(!isset($rule['author']))
			return false;
		global $wp_version;
		if ($wp_version > "2.8")
			return $rule['author'] === get_the_author_meta('ID');
	 	return $rule['author'] === get_the_author_ID();
	}
}

if(!function_exists('VerifyRule_posttype')){
	function VerifyRule_posttype($rule){
		if(!isset($rule['posttype']))
			return false;
	 	return $rule['posttype'] === get_post_type();
	}
}

if(!function_exists('VerifyRule_category')){
	function VerifyRule_tag($rule){
		$op = $_GET[$rule['catop']];
		$id = $_GET[$rule['catid']];
		if(!isset($op) || !isset($id))
			return false;

		switch($op){
			case 'isa': // is the category or a child of the category
				return in_category($id) || post_is_in_descendant_category($id);
				break;
			case 'isnota': // is not the category or a child of the category
				return !in_category($id) && !post_is_in_descendant_category($id);
				break;
		}
		return false;
	}
}

if(!function_exists('VerifyRule_tag')){
	function VerifyRule_tag($rule){
		$op = $_GET[$rule['tagop']];
		$id = $_GET[$rule['tagid']];
		if(!isset($op) || !isset($id))
			return false;

		$posttags = get_the_tags();
		switch($op){
			case 'isa': // has the tag
				$match = true;
				break;
			case 'isnota': // does not have the tag
				$match = false;
				break;
		}
		if($posttags){
			foreach($posttags as $tag) {
				if($tag == $id)
					return $match;
			}
		}
		return !$match;
	}
}

if(!function_exists('VerifyRule_getargument')){
	function VerifyRule_getargument($rule){
		return CompareByOperator($_GET[$rule['argname']], $rule['argop'], $rule['argvalue']);

	}
}

if(!function_exists('VerifyRule_cvar')){
	function VerifyRule_cvar($rule){
		// Verify that we have all the arguments that we need and that the GET argument is set
		foreach(get_option('active_plugins') as $index => $plugin){
			if($plugin == 'virtual-theme/VirtualTheme.php'){
				require_once(WP_PLUGIN_DIR . "/" . $plugin);
				$var = VirtualTheme::GetVirtualVariable($_GET['virtualpath'], $rule['cvarname']);
				return CompareByOperator($var, $rule['cvarop'], $rule['cvarvalue']);
			}
		}
		return false;
	}
}

if(!function_exists('VerifyRule_vpath')){
	function VerifyRule_vpath($rule){
		// Verify that we have all the arguments that we need and that the GET argument is set
		return CompareByOperator($_GET["virtualpath"], $rule['vpathop'], $rule['vpath']);

	}
}

if(!function_exists('VerifyRule_geoip')){
	require_once('Version.php');

	function VerifyRule_geoip_GetGeoLocation($ip, $apiKey){
		$ipLite = new ip2location_lite;
		$ipLite->setKey($apiKey);
		$visitorGeoLocation = $ipLite->getCity($ip);
	  
		if($visitorGeoLocation['statusCode'] == 'OK'){
			$data = base64_encode(serialize($visitorGeoLocation));
			setcookie("geolocation", $data, time()+3600*24*7); //set cookie for 1 week
		}
		return $visitorGeoLocation;
	}

	function VerifyRule_geoip($rule){
		// Verify that we have all the arguments that we need and that the GET argument is set
		include_once('ip2locationlite.class.php');

		global $pluginname;

		//Set geolocation cookie
		$visitorGeoLocation = null;
		if($_COOKIE["geolocation"]){
			$visitorGeoLocation = unserialize(base64_decode($_COOKIE["geolocation"]));
		}

		if(!isset($visitorGeoLocation) || $visitorGeoLocation['ipAddress'] != $_SERVER['REMOTE_ADDR']){
			$options = maybe_unserialize(get_option($pluginname . "_options"));
			$apiKey = $options['settings']['ipinfodbkey'];
			if(!isset($apiKey) || strlen($apiKey) == 0)
				return false;
			$visitorGeoLocation = VerifyRule_geoip_GetGeoLocation($_SERVER['REMOTE_ADDR'], $apiKey);
		}

		if(!isset($visitorGeoLocation) || $visitorGeoLocation['statusCode'] !=  "OK")
			return false;

		$lhs = $visitorGeoLocation[$rule['geolocation']];
		return CompareByOperator($lhs, $rule['geoop'], $rule['geovalue']);

	}
}

